@@ -28,6 +28,9 @@ import nibabel
 import pytest
 from bids.layout import BIDSLayout
 
+# disable ET
+os.environ['NO_ET'] = '1'
+
 test_data_env = os.getenv("TEST_DATA_HOME", str(Path.home() / "sdcflows-tests"))
 test_output_dir = os.getenv("TEST_OUTPUT_DIR")
 test_workdir = os.getenv("TEST_WORK_DIR")
